.. doctest-skip-all

.. _jwst_data_files:

JWST data files (coming soon)
=============================

These data files are needed for calculations involving JWST bandpasses.
Details will be given soon.
